<?php

use Drupal\acquia_search\AcquiaSearchConnectionInterface;

/**
 * Starting point for the Solr API.
 *
 * Represents a Solr server resource and has methods for pinging, adding,
 * deleting, committing, optimizing and searching.
 */
class AcquiaSearchV2ApacheSolr extends DrupalApacheSolrService implements AcquiaSearchConnectionInterface {

  use AcquiaSearchConnectionTrait;

  /**
   * Get derived key for solr hmac using the information shared with acquia.com.
   */
  protected function getDerivedKey() {
    $env_id = $this->env_id;

    static $derived_key = [];
    if (empty($env_id)) {
      $env_id = 0;
    }
    if (!isset($derived_key[$env_id])) {
      // If we set an explicit environment, check if this needs to overridden
      // Use the default.
      $identifier = acquia_agent_settings('acquia_identifier');
      $key = acquia_agent_settings('acquia_key');
      // See if we need to overwrite these values.
      if ($env_id) {
        // Load the explicit environment and a manually set search key.
        if ($search_key = apachesolr_environment_variable_get($env_id, 'acquia_search_key')) {
          $derived_key[$env_id] = $search_key;
        }
      }

      // In any case, this is equal for all subscriptions. Also
      // even if the search sub is different, the main subscription should be
      // active.
      $derived_key_salt = AcquiaSearchAuth::getDerivedKeySalt();
      // We use a salt from acquia.com in key derivation since this is a shared
      // value that we could change on the AN side if needed to force any
      // or all clients to use a new derived key.  We also use a string
      // ('solr') specific to the service, since we want each service using a
      // derived key to have a separate one.
      if (empty($derived_key_salt) || empty($key) || empty($identifier)) {
        // Expired or invalid subscription - don't continue.
        $derived_key[$env_id] = '';
      }
      elseif (!isset($derived_key[$env_id])) {

        // Get the Solr core identifier from the URL, to build the correct
        // derived key.
        $environment = apachesolr_environment_load($env_id);
        if (isset($environment['url'])) {
          $core_id = AcquiaSearch::getCoreIdFromEnvironmentUrl($environment['url']);
          $derived_key[$env_id] = AcquiaSearchAuth::createDerivedKey($derived_key_salt, $core_id, $key);
        }

      }
    }

    return $derived_key[$env_id];
  }

  /**
   * {@inheritdoc}
   */
  public function constructUrl($servlet, $params) {
    return $this->_constructUrl($servlet, $params);
  }

  /**
   * {@inheritdoc}
   */
  public function makeHttpRequest($url, $options = []) {
    return $this->_makeHttpRequest($url, $options);
  }

  /**
   * {@inheritdoc}
   */
  public function getServerId() {
    return $this->env_id;
  }

}
