<?php

use Drupal\acquia_search\AcquiaSearchConnectionInterface;

/**
 * Search v2 API class.
 *
 * Starting point for the Solr API. Represents a Solr server resource and has
 * methods for pinging, adding, deleting, committing, optimizing and searching.
 */
class AcquiaSearchV2SearchApi extends SearchApiSolrConnection implements AcquiaSearchConnectionInterface {

  use AcquiaSearchConnectionTrait;

  /**
   * The derived key used to HMAC hash the search request.
   *
   * @var string
   */
  protected $derivedKey;

  /**
   * Sets the derived key used to HMAC hash the search request.
   *
   * @param string $derived_key
   *   The derived key.
   */
  public function setDerivedKey($derived_key) {
    $this->derivedKey = $derived_key;
  }

  /**
   * Derive a key for the solr hmac using the information from acquia.com.
   *
   * @return string
   *   The derived key.
   */
  public function getDerivedKey() {
    if (!isset($this->derivedKey)) {
      $key = acquia_agent_settings('acquia_key');
      $subscription = acquia_agent_settings('acquia_subscription_data');
      $identifier = acquia_agent_settings('acquia_identifier');
      // We use a salt from acquia.com in key derivation since this is a shared
      // value that we could change on the AN side if needed to force any
      // or all clients to use a new derived key.  We also use a string
      // ('solr') specific to the service, since we want each service using a
      // derived key to have a separate one.
      if (empty($subscription['active']) || empty($key) || empty($identifier)) {
        // Expired or invalid subscription - don't continue.
        $this->derivedKey = '';
      }
      else {
        $salt = AcquiaSearchAuth::getDerivedKeySalt();
        $this->derivedKey = AcquiaSearchAuth::createDerivedKey($salt, $identifier, $key);
      }
    }
    return $this->derivedKey;
  }

  /**
   * {@inheritdoc}
   */
  public function getServerId() {
    return $this->options['server'];
  }

}
